pub fn init_logging()Expand description
Initialize logging from environment variables.
Called automatically on first log attempt, but can be called explicitly to ensure logging is set up early.
pub fn init_logging()Initialize logging from environment variables.
Called automatically on first log attempt, but can be called explicitly to ensure logging is set up early.